@@ -1119,48 +1119,6 @@ END
        ");";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i '/DO NOT MODIFY THIS/a$ad' $user_path");
-   $ad="%NL%=head1 UNIQUE CONSTRAINTS,%NL%".
-       "%NL%".
-       "=head2 C<username_unique>%NL%".
-       "%NL%".
-       "=over 4%NL%".
-       "%NL%".
-       "=item * L</username>%NL%".
-       "%NL%".
-       "=back%NL%".
-       "%NL%".
-       "=cut%NL%".
-       "%NL%".
-       "__PACKAGE__->add_unique_constraint(\"username_unique\", [\"username\"]);%NL%".
-       "%NL%".
-       "=head1 RELATIONS%NL%".
-       "%NL%".
-       "=head2 user_roles%NL%".
-       "%NL%".
-       "Type: has_many%NL%".
-       "%NL%".
-       "Related object: L<FullAutoAPI::Schema::Result::UserRole>%NL%".
-       "%NL%".
-       "=cut%NL%".
-       "%NL%".
-       "__PACKAGE__->has_many(%NL%".
-       "  \"user_roles\",%NL%".
-       "  \"FullAutoAPI::Schema::Result::UserRole\",%NL%".
-       "  { \"foreign.user_id\" => \"self.id\" },%NL%".
-       "  { cascade_copy => 0, cascade_delete => 0 },%NL%".
-       ");%NL%".
-       "%NL%".
-       "=head2 roles%NL%".
-       "%NL%".
-       "Type: many_to_many%NL%".
-       "%NL%".
-       "Composing rels: L</user_roles> -> role%NL%".
-       "%NL%".
-       "=cut%NL%".
-       "%NL%".
-       "__PACKAGE__->many_to_many(\"roles\", \"user_roles\", \"role\");";
-   ($stdout,$stderr)=$handle->cmd(
-      "${sudo}sed -i '/set_primary_key/a$ad' $user_path");
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $user_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $user_path");
